@@ -1,6 +1,6 @@
 package Bundle::Lingua::PT;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =head1 NAME
 
@@ -11,12 +11,22 @@ Language Processing of the Portuguese
 
 cpan Bundle::Lingua::PT
 
+=head1 DESCRIPTION
+
+This module includes some specific modules related to Natural Language
+Processing of the Portuguese language, as well as some others we find
+useful to have when doing this kind of task.
+
+If you think some useful module is missing let us know.
+
 =head1 CONTENTS
 
 Text::Ngram
 
 Text::Affixes
 
+Lingua::Identify
+
 Lingua::PT::Abbrev
 
 Lingua::PT::Conjugate
@@ -39,6 +49,8 @@ Lingua::PT::ProperNames
 
 Lingua::PT::Words2Nums
 
+Lingua::PT::Speaker
+
 =head1 AUTHOR
 
 Alberto Simes, C<< <ambs@cpan.org> >>
@@ -47,7 +59,7 @@ Jos Castro, C<< <cog@cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2004 Alberto Simes and Jos Castro, All Rights Reserved.
+Copyright 2005 Alberto Simes and Jos Castro, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
